==> haskell-regex-applicative-text-0.1.0.1-241-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-8mUlHGX4UY7FfLH2JgFUgM
key:                  regex-applicative-text-0.1.0.1-8mUlHGX4UY7FfLH2JgFUgM
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  7910c31a44272ac43040e2dcc37569a0
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-8mUlHGX4UY7FfLH2JgFUgM
depends:
    base-4.17.2.1 regex-applicative-0.3.4-1EESOJFmR9fCtBlJiaQyq9
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-text-0.1.0.1-244-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-BloJSwlnJit5x8guBoKjGA
key:                  regex-applicative-text-0.1.0.1-BloJSwlnJit5x8guBoKjGA
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  42547e7c917c103d3f2aa0739f0e21a0
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-BloJSwlnJit5x8guBoKjGA
depends:
    base-4.17.2.1 regex-applicative-0.3.4-8fRPVZU7sxt8L2tVC8a9fP
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
